summaryrefslogtreecommitdiffstats
path: root/kicker/menuext/konsole/konsolebookmarkmenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext/konsole/konsolebookmarkmenu.cpp')
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index 0860cc123..840b3b8f6 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
- TQT_SLOT( slotAboutToShow() ) );
- connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
- TQT_SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQ_SIGNAL( aboutToShow() ), this,
+ TQ_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQ_SIGNAL( aboutToShow() ),
+ TQ_SLOT( slotAboutToShow2() ) );
}
/*
@@ -100,8 +100,8 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
m_actionCollection, false,
m_bAddBookmark, TQString::null );
m_lstSubMenus.append(subMenu);
- connect( actionMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), subMenu,
- TQT_SLOT(slotNSLoad()));
+ connect( actionMenu->popupMenu(), TQ_SIGNAL(aboutToShow()), subMenu,
+ TQ_SLOT(slotNSLoad()));
}
}
@@ -128,7 +128,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
TDEAction * action = new TDEAction( text, bm.icon(), 0,
- this, TQT_SLOT( slotBookmarkSelected() ),
+ this, TQ_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -168,7 +168,7 @@ void KonsoleBookmarkMenu::slotBookmarkSelected()
if ( !m_pOwner ) return; // this view doesn't handle bookmarks...
a = (TDEAction*)sender();
b = a->text();
- m_kOwner->openBookmarkURL( TQString::fromUtf8(TQT_TQOBJECT_CONST(sender())->name()), /* URL */
+ m_kOwner->openBookmarkURL( TQString::fromUtf8(sender()->name()), /* URL */
( (TDEAction *)sender() )->text() /* Title */ );
}
@@ -177,7 +177,7 @@ void KonsoleBookmarkMenu::slotNSBookmarkSelected()
TDEAction *a;
TQString b;
- TQString link(TQT_TQOBJECT_CONST(sender())->name()+8);
+ TQString link(sender()->name()+8);
a = (TDEAction*)sender();
b = a->text();
m_kOwner->openBookmarkURL( link, /*URL */
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the TQT_SLOT() macro thinks we want
+ * They are named differently because the TQ_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?